=======
Credits
=======

Authors
=======

Development Lead
----------------

* Robert Grant <rhgrant10@gmail.com>

Contributors
------------

* Robert Graham <rpgraham84@gmail.com>


Miscellaneous
=============

This package was created with Cookiecutter_ and the
`audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
